InstallSnapshotRequest

Struct InstallSnapshotRequest 

pub struct InstallSnapshotRequest {
    pub term: Term,
    pub leader_id: NodeId,
    pub last_included_index: LogIndex,
    pub last_included_term: Term,
    pub offset: u64,
    pub data: Vec<u8>,
    pub done: bool,
}
InstallSnapshot RPC request (Raft paper Section 7)

Sent by the leader to followers that are too far behind in the log. The snapshot is sent in chunks identified by offset and done flag.

Fields

term: Term

Leader’s current term

leader_id: NodeId

Leader’s ID so follower can redirect clients

last_included_index: LogIndex

The last included index in the snapshot

last_included_term: Term

The term of the last included index

offset: u64

Byte offset into the snapshot data for chunked transfer

data: Vec<u8>

Raw snapshot data chunk

done: bool

True if this is the final chunk of the snapshot

Implementations

Source

impl InstallSnapshotRequest

pub fn new_complete( term: Term, leader_id: NodeId, last_included_index: LogIndex, last_included_term: Term, data: Vec<u8>, ) -> Self

Create a new InstallSnapshot request for a complete snapshot (single chunk)

pub fn new_chunk( term: Term, leader_id: NodeId, last_included_index: LogIndex, last_included_term: Term, offset: u64, data: Vec<u8>, done: bool, ) -> Self

Create a new InstallSnapshot request for a chunk of a snapshot

pub fn is_complete(&self) -> bool

Check if this is a complete (non-chunked) snapshot transfer