pub struct ClusterConfig { /* private fields */ }Expand description
Tracks cluster members with their addresses and a monotonically increasing version
Implementations
Sourceimpl ClusterConfig
impl ClusterConfig
Sourcepub fn new(members: Vec<(NodeId, String)>, version: u64) -> Self
pub fn new(members: Vec<(NodeId, String)>, version: u64) -> Self
Create a new cluster config with the given members and version
Sourcepub fn member_ids(&self) -> HashSet<NodeId>
pub fn member_ids(&self) -> HashSet<NodeId>
Get the list of member node IDs
Sourcepub fn quorum_size(&self) -> usize
pub fn quorum_size(&self) -> usize
Get the majority quorum size for this config
Sourcepub fn with_added_member(&self, node_id: NodeId, address: String) -> Self
pub fn with_added_member(&self, node_id: NodeId, address: String) -> Self
Add a member to the config, returning a new config with incremented version
Sourcepub fn without_member(&self, node_id: NodeId) -> Self
pub fn without_member(&self, node_id: NodeId) -> Self
Remove a member from the config, returning a new config with incremented version