FailoverEvent

Enum FailoverEvent 

pub enum FailoverEvent {
    LeaderLost {
        old_leader: NodeId,
        election_triggered: bool,
    },
    LeaderElected {
        new_leader: NodeId,
    },
    FailoverTimeout,
    PeerFailed {
        node_id: NodeId,
    },
    PeerRecovered {
        node_id: NodeId,
    },
}
Events produced by the FailoverCoordinator during each tick.

Variants



LeaderLost

The current leader has been detected as failed and an election has been scheduled (after the jitter delay expires).

Fields

old_leader: NodeId

Node ID of the old leader.

election_triggered: bool

Whether an election timer was started as a result.



LeaderElected

A new leader has been acknowledged (set via FailoverCoordinator::set_leader).

Fields

new_leader: NodeId

Node ID of the new leader.



FailoverTimeout

The election jitter timer expired without a new leader being set.



PeerFailed

A non-leader peer has failed.

Fields

node_id: NodeId

The failed peer.



PeerRecovered

A previously-failed peer has recovered.

Fields

node_id: NodeId

The recovered peer.